@@ -19,7 +19,10 @@ import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-serverless-lamp", "1.3.5", __name__[0:-6], "cdk-serverless-lamp@1.3.5.jsii.tgz"
+    "cdk-serverless-lamp",
+    "1.3.10",
+    __name__[0:-6],
+    "cdk-serverless-lamp@1.3.10.jsii.tgz",
 )
 
 __all__ = [
